@@ -6,6 +6,7 @@ function(mf, ncol_intercepts = 0){
   col_chosen_inter <- array(dim = 0) # store interactions without numeric variables
   col_chosen_inter_numeric <- array(dim = 0) # store interactions with numeric variables, used for mean centering
   results <- list()
+  results_num <- list()
   if (length(col_index_inter) > 0){
     for (i in 1:length(col_index_inter)){
       index_inter <- which(factor_matrix[,col_index_inter[i]] == 1) # order matters
@@ -14,12 +15,15 @@ function(mf, ncol_intercepts = 0){
         results[[i]] <- index_inter + ncol_intercepts
         col_chosen_inter <- c(col_chosen_inter, col_index_inter[i] + ncol_intercepts)
       }else{
+        results_num[[i]] <- index_inter + ncol_intercepts
         col_chosen_inter_numeric <- c(col_chosen_inter_numeric, col_index_inter[i] + ncol_intercepts)
       }
+      
     }
   }
   sol <- list()
   sol$results <- results
+  sol$results_num <- results_num
   sol$index <- col_chosen_inter
   sol$numeric_index <- col_chosen_inter_numeric
   return(sol)
